@@ -86,6 +86,10 @@
     if (ptr_##fn) {                         \
         return ptr_##fn(a1, a2, a3, a4);    \
     }
+#define STUB_SAFE_CALL5(fn, a1, a2, a3, a4, a5) \
+    if (ptr_##fn) {                             \
+        return ptr_##fn(a1, a2, a3, a4, a5);    \
+    }
 #define STUB_SAFE_CALL6(fn, a1, a2, a3, a4, a5, a6) \
     if (ptr_##fn) {                                 \
         return ptr_##fn(a1, a2, a3, a4, a5, a6);    \
@@ -140,6 +144,7 @@ STUB_DECLARE(void, PORT_Free_Util, (void *ptr));
 STUB_DECLARE(void, PORT_FreeArena_Util, (PLArenaPool * arena, PRBool zero));
 STUB_DECLARE(int, PORT_GetError_Util, (void));
 STUB_DECLARE(PLArenaPool *, PORT_NewArena_Util, (unsigned long chunksize));
+STUB_DECLARE(void, PORT_SafeZero, (void *p, size_t n));
 STUB_DECLARE(void, PORT_SetError_Util, (int value));
 STUB_DECLARE(void *, PORT_ZAlloc_Util, (size_t len));
 STUB_DECLARE(void *, PORT_ZAllocAligned_Util, (size_t bytes, size_t alignment, void **mem));
@@ -177,6 +182,10 @@ STUB_DECLARE(void, SECITEM_ZfreeItem_Util, (SECItem * zap, PRBool freeit));
 STUB_DECLARE(SECOidTag, SECOID_FindOIDTag_Util, (const SECItem *oid));
 STUB_DECLARE(int, NSS_SecureMemcmp, (const void *a, const void *b, size_t n));
 STUB_DECLARE(unsigned int, NSS_SecureMemcmpZero, (const void *mem, size_t n));
+STUB_DECLARE(void, NSS_SecureSelect, (void *dest, const void *src0, const void *src1, size_t n, unsigned char b));
+#ifndef NSS_FIPS_DISABLED
+STUB_DECLARE(PRBool, NSS_GetSystemFIPSEnabled, (void));
+#endif
 
 #define PORT_ZNew_stub(type) (type *)PORT_ZAlloc_stub(sizeof(type))
 #define PORT_New_stub(type) (type *)PORT_Alloc_stub(sizeof(type))
@@ -480,6 +489,20 @@ PORT_GetError_stub(void)
     return errno;
 }
 
+extern void
+PORT_SafeZero(void *p, size_t n)
+{
+    STUB_SAFE_CALL2(PORT_SafeZero, p, n);
+    /* just use a generic call in the case where we are running
+     * standalone freebl */
+    if (p != NULL) {
+        volatile unsigned char *__vl = (unsigned char *)p;
+        size_t __nl = n;
+        while (__nl--)
+            *__vl++ = 0;
+    }
+}
+
 extern void
 PORT_SetError_stub(int value)
 {
@@ -700,6 +723,54 @@ NSS_SecureMemcmpZero_stub(const void *mem, size_t n)
     abort();
 }
 
+extern void
+NSS_SecureSelect_stub(void *dest, const void *src0, const void *src1, size_t n, unsigned char b)
+{
+    STUB_SAFE_CALL5(NSS_SecureSelect, dest, src0, src1, n, b);
+    abort();
+}
+
+#ifndef NSS_FIPS_DISABLED
+PRBool
+NSS_GetSystemFIPSEnabled_stub(void)
+{
+    STUB_SAFE_CALL0(NSS_GetSystemFIPSEnabled);
+    const char *env;
+
+    /* The environment variable is active for all platforms */
+    env = PR_GetEnvSecure_stub("NSS_FIPS");
+    /* we generally accept y, Y, 1, FIPS, TRUE, and ON as turning on FIPS
+     * mode. Anything else is considered 'off' */
+    if (env && (*env == 'y' || *env == '1' || *env == 'Y' ||
+                (strcasecmp(env, "fips") == 0) ||
+                (strcasecmp(env, "true") == 0) ||
+                (strcasecmp(env, "on") == 0))) {
+        return PR_TRUE;
+    }
+
+/* currently only Linux has a system FIPS indicator. Add others here
+ * as they become available/known */
+#ifdef LINUX
+    {
+        FILE *f;
+        char d;
+        size_t size;
+        f = fopen("/proc/sys/crypto/fips_enabled", "r");
+        if (!f)
+            return PR_FALSE;
+
+        size = fread(&d, 1, 1, f);
+        fclose(f);
+        if (size != 1)
+            return PR_FALSE;
+        if (d == '1')
+            return PR_TRUE;
+    }
+#endif /* LINUX */
+    return PR_FALSE;
+}
+#endif /* NSS_FIPS_DISABLED = 0 */
+
 #ifdef FREEBL_NO_WEAK
 
 static const char *nsprLibName = SHLIB_PREFIX "nspr4." SHLIB_SUFFIX;
@@ -753,6 +824,7 @@ freebl_InitNSSUtil(void *lib)
     STUB_FETCH_FUNCTION(SECOID_FindOIDTag_Util);
     STUB_FETCH_FUNCTION(NSS_SecureMemcmp);
     STUB_FETCH_FUNCTION(NSS_SecureMemcmpZero);
+    STUB_FETCH_FUNCTION(NSS_SecureSelect);
     return SECSuccess;
 }
 
